#!/usr/bin/env python
# coding: utf-8

from setuptools import setup

setup(
    name='pynkdv',
    version='0.0.3',
    author='rui',
    author_email='19251017@life.hkbu.edu.hk',
    url='https://zhuanlan.zhihu.com/p/26159930',
    description='for nkdv in python',
    packages=['pynkdv'],
    install_requires=['nkdv'],
    entry_points={
    }
)